@@ -50,16 +50,16 @@ class account():
     def __init__(self, osso_c, accData, controller):
         self.controller = controller
         #these store all the data associated with this accounts tweets
-        # the fields are : Name,sender_id,Tweet,TweetColour,id, type, timestamp, replyTo, source
-        self.tweetstore = gtk.ListStore(str, str, str, str, str, str, str, str, str, gtk.gdk.Pixbuf, str)
+        # the fields are : Name,sender_id,Tweet,TweetColour,id, type, timestamp, replyTo, source, pic, formatted_tweet
+        self.tweetstore = gtk.ListStore(str, str, str, str, str, str, gobject.TYPE_PYOBJECT , str, str, gtk.gdk.Pixbuf, str)
         #then we want the same again to store dm's, mentions & pubilc timeline separately
-        self.dmstore = gtk.ListStore(str, str, str, str, str, str, str, str, str, gtk.gdk.Pixbuf, str)
-        self.mentionstore = gtk.ListStore(str, str, str, str, str, str, str, str, str, gtk.gdk.Pixbuf, str)
-        self.publicstore = gtk.ListStore(str, str, str, str, str, str, str, str, str, gtk.gdk.Pixbuf, str)
-        self.trendstore = gtk.ListStore(str, str, str, str, str, str, str, str, str, gtk.gdk.Pixbuf, str)
-        self.friendsstore = gtk.ListStore(str, str, str, str, str, str, str, str, str, gtk.gdk.Pixbuf, str)
-        self.searchstore = gtk.ListStore(str, str, str, str, str, str, str, str, str, gtk.gdk.Pixbuf, str)
-        self.userhistorystore = gtk.ListStore(str, str, str, str, str, str, str, str, str, gtk.gdk.Pixbuf, str)
+        self.dmstore = gtk.ListStore(str, str, str, str, str, str, gobject.TYPE_PYOBJECT, str, str, gtk.gdk.Pixbuf, str)
+        self.mentionstore = gtk.ListStore(str, str, str, str, str, str, gobject.TYPE_PYOBJECT, str, str, gtk.gdk.Pixbuf, str)
+        self.publicstore = gtk.ListStore(str, str, str, str, str, str, gobject.TYPE_PYOBJECT, str, str, gtk.gdk.Pixbuf, str)
+        self.trendstore = gtk.ListStore(str, str, str, str, str, str, gobject.TYPE_PYOBJECT, str, str, gtk.gdk.Pixbuf, str)
+        self.friendsstore = gtk.ListStore(str, str, str, str, str, str, gobject.TYPE_PYOBJECT, str, str, gtk.gdk.Pixbuf, str)
+        self.searchstore = gtk.ListStore(str, str, str, str, str, str, gobject.TYPE_PYOBJECT, str, str, gtk.gdk.Pixbuf, str)
+        self.userhistorystore = gtk.ListStore(str, str, str, str, str, str, gobject.TYPE_PYOBJECT, str, str, gtk.gdk.Pixbuf, str)
         #store of avatar, filename, access count
         self.avatars = gtk.ListStore(gtk.gdk.Pixbuf, str, int, str)
         #base url can be set to any twitter compatible site, so we can support mutliple account types
@@ -214,9 +214,10 @@ class account():
                  text = self.controller.expandBitlyUrls(text)
                  pic = self.set_pic_for_id(str(x.user.GetId()), x.user.GetScreenName(), x.user.GetProfileImageUrl())
                  created_at = self.parse_time(x.created_at)
-                 formatted_tweet = self.format_tweet(x.user.screen_name, text, created_at, source, reply_to)
-
-                 self.tweetstore.append([ "@" + x.user.screen_name, str(x.user.GetId()), "@" + x.user.screen_name + " : " + text, "", x.id, "Tweet", x.created_at, reply_to, source, pic, formatted_tweet])
+                 formatted_ts = self.format_timestamp(created_at)
+                 formatted_tweet = self.format_tweet(x.user.screen_name, text, formatted_ts, source, reply_to)
+                 
+                 self.tweetstore.append([ "@" + x.user.screen_name, str(x.user.GetId()), "@" + x.user.screen_name + " : " + text, "", x.id, "Tweet", created_at, reply_to, source, pic, formatted_tweet])
                  receive_count = receive_count + 1
 
             if (receive_count > 0):
@@ -296,7 +297,8 @@ class account():
                  text = self.controller.expandBitlyUrls(text)
                  pic = self.set_pic_for_id(str(x.user.GetId()), x.user.GetScreenName(), x.user.GetProfileImageUrl())
                  created_at = self.parse_time(x.created_at)
-                 formatted_tweet = self.format_tweet(x.user.screen_name, text, created_at, source, reply_to)
+                 formatted_ts = self.format_timestamp(created_at)
+                 formatted_tweet = self.format_tweet(x.user.screen_name, text, formatted_ts, source, reply_to)
                  self.mentionstore.append([ "@" + x.user.screen_name, str(x.user.GetId()), "@" + x.user.screen_name + " : " + text, "", x.id, "Tweet", x.created_at, reply_to, source, pic, formatted_tweet])
                  receive_count = receive_count + 1
 
@@ -368,7 +370,8 @@ class account():
                  text = self.controller.expandBitlyUrls(text)
                  pic = self.set_pic_for_id(str(x.GetSenderId()), x.GetSenderScreenName(), "")
                  created_at = self.parse_time(x.created_at)
-                 formatted_tweet = self.format_tweet(user, text, created_at, None, None)
+                 formatted_ts = self.format_timestamp(created_at)
+                 formatted_tweet = self.format_tweet(user, text, formatted_ts, None, None)
                  self.dmstore.append([ "@" + user, x.GetSenderId(), "@" + user + " : " + text, "", x.id, "Tweet", x.created_at, "", "", pic, formatted_tweet])
                  receive_count = receive_count + 1
 
@@ -422,7 +425,8 @@ class account():
                     source = self.getSourceAppname(source)
                     pic = self.set_pic_for_id(str(x.id), x.GetScreenName(), x.GetProfileImageUrl())
                     created_at = self.parse_time(tweettime)
-                    formatted_tweet = self.format_tweet(x.screen_name, status, created_at, source, None)
+                    formatted_ts = self.format_timestamp(created_at)
+                    formatted_tweet = self.format_tweet(x.screen_name, status, formatted_ts, source, None)
                     self.friendsstore.append([ "@" + x.screen_name, str(x.id), "@" + x.screen_name + " : " + status, "", x.id, "friend", tweettime, "", source, pic, formatted_tweet])
                     receive_count = receive_count + 1
 
@@ -502,7 +506,8 @@ class account():
                  text = self.controller.expandBitlyUrls(text)
                  pic = self.set_pic_for_id(str(x.user.GetId()), x.user.GetScreenName(), x.user.GetProfileImageUrl())
                  created_at = self.parse_time(x.created_at)
-                 formatted_tweet = self.format_tweet(x.user.screen_name, text, created_at, source, reply_to)
+                 formatted_ts = self.format_timestamp(created_at)
+                 formatted_tweet = self.format_tweet(x.user.screen_name, text, formatted_ts, source, reply_to)
                  self.publicstore.append([ "@" + x.user.screen_name, x.user.GetId(), "@" + x.user.screen_name + " : " + text, "", x.id, "Tweet", x.created_at, reply_to, source, pic, formatted_tweet])
                  receive_count = receive_count + 1
 
@@ -558,7 +563,8 @@ class account():
                  text = self.controller.expandBitlyUrls(text)
                  pic = self.set_pic_for_id(str(x.user.GetId()), x.user.GetScreenName(), x.user.GetProfileImageUrl())
                  created_at = self.parse_time(x.created_at)
-                 formatted_tweet = self.format_tweet(x.user.screen_name, text, created_at, source, reply_to)
+                 formatted_ts = self.format_timestamp(created_at)
+                 formatted_tweet = self.format_tweet(x.user.screen_name, text, formatted_ts, source, reply_to)
                  self.userhistorystore.append([ "@" + x.user.screen_name, x.user.GetId(), "@" + x.user.screen_name + " : " + text, "", x.id, "Tweet", x.created_at, reply_to, source, pic, formatted_tweet])
                  receive_count = receive_count + 1
 
@@ -628,7 +634,8 @@ class account():
                     print "search result from userid: " + str(x['from_user_id'])
                     pic = self.get_pic_for_name(str(x['from_user']))
                     created_at = self.parse_time(x['created_at'])
-                    formatted_tweet = self.format_tweet(x['from_user'], text, created_at, source, reply_to)
+                    formatted_ts = self.format_timestamp(created_at)
+                    formatted_tweet = self.format_tweet(x['from_user'], text, formatted_ts, source, reply_to)
                     self.searchstore.append([ "@" + x['from_user'], str(x['from_user_id']), "@" + x['from_user'] + " : " + text, "", x['id'], "Search", x['created_at'], reply_to, source, pic, formatted_tweet])
                     receive_count = receive_count + 1
                     note = osso.SystemNote(self.osso_c)
@@ -689,7 +696,7 @@ class account():
 
 
 
-    def get_specific_tweet(self, screen_name, tweet_id):
+    def get_specific_tweet(self,username,tweet_id):
         try:
             data = self.api.GetStatus(tweet_id)
             return data.text
@@ -1010,11 +1017,10 @@ class account():
         print timestamp
 
         dt = msgDate
-        nowstring = timestamp.strftime('%a, %b %d %Y %H:%M:%S')  # %Z (timezone) would be empty
-        #nowstring = "%s%s" % (dts, mytz)
-
-        print nowstring
-        return nowstring
+        return timestamp
+    
+    def format_timestamp(self,timestamp):
+        return timestamp.strftime('%a, %b %d %Y %H:%M:%S')  # %Z (timezone) would be empty
 
 
 
